package Net::OpenStack::Attack;

our $VERSION = '1.0000'; # VERSION

# ABSTRACT: Tools for stress testing an OpenStack deployment.


1;

__END__
=pod

=head1 NAME

Net::OpenStack::Attack - Tools for stress testing an OpenStack deployment.

=head1 VERSION

version 1.0000

=head1 DESCRIPTION

You probably want to look at the documentation for L<stackattack> instead.

=head1 AUTHORS

=over 4

=item *

William Wolf <throughnothing@gmail.com>

=item *

Naveed Massjouni <naveedm9@gmail.com>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2011 by Naveed Massjouni.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

